#
# spec file for package perl-Term-ReadLine-Gnu
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Term-ReadLine-Gnu
Name:           perl-Term-ReadLine-Gnu
Version:        1.46
Release:        bp160.1.6
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl extension for the GNU Readline/History Library
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HA/HAYASHI/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  ncurses-devel
BuildRequires:  readline-devel
Obsoletes:      perl-TermReadLine-Gnu < 1.36
Provides:       perl-TermReadLine-Gnu = %{version}
# MANUAL END

%description
This is an implementation of Term::ReadLine using the GNU Readline/History
Library.

For basic functions object oriented interface is provided. These are
described in the section "Standard Methods" and "Term::ReadLine::Gnu
Functions".

This package also has the interface with the almost all functions and
variables which are documented in the GNU Readline/History Library Manual.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md

%changelog
* Sun Jul  2 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.46
  see /usr/share/doc/packages/perl-Term-ReadLine-Gnu/Changes
  1.46  2023-07-01
  - Reproduce Term::ReadLine::Stub’s behavior for ornaments (#17)
  - The Perl debugger uses these control sequences for online help
  - fetch the control sequences for outputting bold text as the
  current Term::ReadLine does
  - let new() fail on multiple instantiation (#16)
  - suppress warning errors on clang
  - add prototype on every function declaration
  - use ANSI-C style port definition even for XS code
  - make clean removes `*.dSYM` for macOS
  - INSTALL.md: update content
  - add install procedure using packages
  - update and remove old descriptions
* Mon Nov 28 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.45
  see /usr/share/doc/packages/perl-Term-ReadLine-Gnu/Changes
  1.45  2022-11-27
  - add support MSWin32
  - require the GNU Readline Library 8.1 or later
  - use xfree in the GNU Readline Library
  - INSTALL.md: add section "MSWin32 (Strawberry Perl)"
  - Makefile.PL
  - On macOS Big Sur or later 'perl Makefile.PL' does not warn any
  more without using ExtUtils::MakeMaker 7.58 or later.
  - ppport.h: update from version 3.62 to version 3.68.
  - suppress warning messages, Wcompound-token-split-by-macro,
  generated by clang 12 or later
  - https://github.com/Perl/perl5/issues/18780
  - expand tabs, trim trailing white-spaces
* Mon Nov  7 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.44
  see /usr/share/doc/packages/perl-Term-ReadLine-Gnu/Changes
  1.44  2022-11-06
  - change the TERM check as bash does (#11)
  - Use `Term::ReadLine::Stub` if the environment variable `TERM` is
  set to `"emacs"` or the environment variable `INSIDE_EMACS` or
  `EMACS` is defined.
* Sun Oct  2 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.43
  see /usr/share/doc/packages/perl-Term-ReadLine-Gnu/Changes
  1.43  2022-09-27
  - readline-8.2 support
  new functions
  rl_trim_arg_from_keyseq
  rl_set_timeout
  rl_clear_timeout
  rl_timeout_remaining
  new variables
  rl_eof_found
  rl_timeout_event_hook
  new state values for rl_readline_state
  RL_STATE_TIMEOUT
  RL_STATE_EOF
  - t/00checkver.t: check if $TERM is set properly [#11]
  - Makefile.PL
  - warn if $TERM is not set properly [#11]
  - fix for MSYS2: take care of `\r\n` in the output of rlmalloc
  - guess_malloc_names(): simplify the control structure
  - INSTALL: add a section for "MSYS2"
  - Gnu.xs: no more non-ANSI C compiler support (remove PARAM macros)
  - Gnu.pm, Gnu.xs, Gnu/XS.pm: expand tabs
  - README.md, INSTALL.md: changed to Markdown
* Mon May 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.42
  see /usr/share/doc/packages/perl-Term-ReadLine-Gnu/Changes
* Sun May  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.41
  see /usr/share/doc/packages/perl-Term-ReadLine-Gnu/Changes
  1.41  2021-05-01
  - Makefile.PL
  - Search a terminal library only when it necessary. [#6]
  - whole refactoring
* Wed Feb 24 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.40
  see /usr/share/doc/packages/perl-Term-ReadLine-Gnu/Changes
* Mon Dec 28 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.37
  see /usr/share/doc/packages/perl-Term-ReadLine-Gnu/Changes
* Sun Jan 27 2019 Stephan Kulow <coolo@suse.com>
- add cpanspec.yml for autoupdates
* Fri Jan 25 2019 ncutler@suse.com
- spec: obsolete "perl-TermReadLine-Gnu" (wrongly-named package in
  Factory/Leap/SLE) (boo#966042)
* Mon Jan 14 2019 Shyukri Shyukriev <shshyukriev@suse.com>
- Update to 1.36 (trying to fix bnc#966042)
  - readline-8.0 support
    new function
    rl_empty_keymap
    rl_set_keymap_name
    rl_check_signals
    new variable
    history_quoting_state
    rl_function_of_keyseq uses rl_function_of_keyseq_len to
    support an arbitrary key sequence that may include NULs.
  - new() checks the number of arguments.
  - make 'use Term::ReadLine::Gnu' fail if $TERM is not set or
    on a dumb terminal.  'use Term::ReadLine' uses
    Term::ReadLine::Stub instead. [rt.cpan.org #123398]
  - Makefile.PL: checks the tinfo library for Debian.
  - add t/01test_use.t and t/02test_use.t.
  - comment out a hack for the CPAN Test on OpenBSD added on
    TRG 1.22.
  - t/utf8_binary.t, t/utf8_text.t: skipped on Perl 5.8.
* Mon Aug 11 2014 ncutler@suse.com
- initial submission of upstream version 1.24 to devel:languages:perl
- check license
- take over maintainership
